"""Setup derived from sample.

References
----------

	<https://packaging.python.org/en/latest/distributing.html>
	<https://github.com/pypa/sampleproject>
"""
import os
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open

# Markdown README used for Github.
project_dir = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(project_dir, 'README.md')
with open(readme_path, encoding='utf-8') as f:
	long_description = f.read()

setup(
	name='vdd',

	# Versions should comply with PEP440.  For a discussion on single-sourcing
	# the version across setup.py and the project code, see
	# https://packaging.python.org/en/latest/single_source_version.html
	version='0.3.2',

	description='Tools to assist value-driven design & decisions',
	long_description=long_description,
	long_description_content_type='text/markdown',

	# The project's main homepage.
	url='https://github.com/corriander/vdd',

	download_url='https://github.com/corriander/vdd/archive/v0.3.2.tar.gz',

	# Author details
	author='Alex Corrie',
	author_email='ajccode@gmail.com',

	# Choose your license
	license='MIT',

	# See https://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 3 - Alpha',

		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Intended Audience :: Information Technology',
		'Intended Audience :: Science/Research',
		'Intended Audience :: Manufacturing',
		'Topic :: Scientific/Engineering :: Information Analysis',

		# Pick your license as you wish (should match "license" above)
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.7'
	],

	# What does your project relate to?
	keywords='design engineering requirements analysis',

	# You can just specify the packages manually here if your project is
	# simple. Or you can use find_packages().
	packages=find_packages(exclude=['contrib', 'docs', 'tests']),

	# Alternatively, if you want to distribute just a my_module.py, uncomment
	# this:
	#   py_modules=["my_module"],

	# List run-time dependencies here.  These will be installed by pip when
	# your project is installed. For an analysis of "install_requires" vs pip's
	# requirements files see:
	# https://packaging.python.org/en/latest/requirements.html
	install_requires=['numpy', 'pandas', 'pygsheets', 'xdg==1.0.5'],

	# List additional groups of dependencies here (e.g. development
	# dependencies). You can install these using the following syntax,
	# for example:
	# $ pip install -e .[dev,test]
	extras_require={
		'test': ['coverage', 'mock', 'ddt'],
	},

)
